import { ActivatedRoute, Router, CanActivate } from '@angular/router';
import { Http, Response, Headers, RequestOptionsArgs } from '@angular/http';
import { Observable } from 'rxjs/Observable';
import 'rxjs/add/operator/share';
import 'rxjs/add/observable/interval';
import 'rxjs/add/observable/fromEvent';
import 'rxjs/add/operator/pluck';
import 'rxjs/add/operator/filter';
import { SignInData, RegisterData, UpdatePasswordData, ResetPasswordData, UserType, UserData, AuthData, Angular2TokenOptions } from './angular2-token.model';
export declare class Angular2TokenService implements CanActivate {
    protected http: Http;
    protected activatedRoute: ActivatedRoute;
    protected router: Router;
    readonly currentUserType: string;
    readonly currentUserData: UserData;
    readonly currentAuthData: AuthData;
    readonly currentAuthHeaders: Headers;
    protected atOptions: Angular2TokenOptions;
    protected atCurrentUserType: UserType;
    protected atCurrentAuthData: AuthData;
    protected atCurrentUserData: UserData;
    constructor(http: Http, activatedRoute: ActivatedRoute, router: Router);
    userSignedIn(): boolean;
    canActivate(): boolean;
    init(options?: Angular2TokenOptions): void;
    /**
     *
     * Actions
     *
     */
    registerAccount(registerData: RegisterData): Observable<Response>;
    deleteAccount(): Observable<Response>;
    signIn(signInData: SignInData): Observable<Response>;
    signInOAuth(oAuthType: string): Observable<any>;
    processOAuthCallback(): void;
    signOut(): Observable<Response>;
    validateToken(): Observable<Response>;
    updatePassword(updatePasswordData: UpdatePasswordData): Observable<Response>;
    resetPassword(resetPasswordData: ResetPasswordData): Observable<Response>;
    /**
     *
     * HTTP Wrappers
     *
     */
    get(url: string, options?: RequestOptionsArgs): Observable<Response>;
    post(url: string, body: any, options?: RequestOptionsArgs): Observable<Response>;
    put(url: string, body: any, options?: RequestOptionsArgs): Observable<Response>;
    delete(url: string, options?: RequestOptionsArgs): Observable<Response>;
    patch(url: string, body: any, options?: RequestOptionsArgs): Observable<Response>;
    head(path: string, options?: RequestOptionsArgs): Observable<Response>;
    options(url: string, options?: RequestOptionsArgs): Observable<Response>;
    request(options: RequestOptionsArgs): Observable<Response>;
    protected mergeRequestOptionsArgs(options: RequestOptionsArgs, addOptions?: RequestOptionsArgs): RequestOptionsArgs;
    protected handleResponse(response: Observable<Response>): void;
    /**
     *
     * Get Auth Data
     *
     */
    protected tryLoadAuthData(): void;
    protected getAuthHeadersFromResponse(data: any): void;
    protected getAuthDataFromPostMessage(data: any): void;
    protected getAuthDataFromStorage(): void;
    protected getAuthDataFromParams(): void;
    /**
     *
     * Set Auth Data
     *
     */
    protected setAuthData(authData: AuthData): void;
    /**
     *
     * Validate Auth Data
     *
     */
    protected checkAuthData(authData: AuthData): boolean;
    /**
     *
     * Construct Paths / Urls
     *
     */
    protected getUserPath(): string;
    protected getApiPath(): string;
    protected getOAuthPath(oAuthType: string): string;
    protected getOAuthUrl(oAuthPath: string, callbackUrl: string, windowType: string): string;
    /**
     *
     * OAuth
     *
     */
    protected requestCredentialsViaPostMessage(authWindow: any): Observable<any>;
    protected oAuthWindowResponseFilter(data: any): any;
    /**
     *
     * Utilities
     *
     */
    protected getUserTypeByName(name: string): UserType;
}
